@@ -31,14 +31,14 @@ def return_confusion_metric(y_true, y_score, normalize=False):
     """
     Computes a confusion metric as absolute difference between the y_true and y_score.
 
-    If normalize eis set to tru, it will normalize y_score to the maximum value in the array
+    If normalize is set to true, it will normalize y_score to the maximum value in the array
 
     Args:
         y_true: (np.ndarray or pd.Series) true targets
         y_score: (np.ndarray or pd.Series) model output
         normalize: boolean, normalize or not to the maximum value
 
-    Returns: (np.ndarray or pd.Series) conflusion metric
+    Returns: (np.ndarray or pd.Series) confusion metric
 
     """
 
@@ -140,7 +140,7 @@ class InspectorShap(BaseInspector):
     """
     Class to perform inspection of the model prediction based on Shapley values.
 
-    It uses the calculated shapley values for the train model to build clusters in the shap space.
+    It uses the calculated Shapley values for the train model to build clusters in the shap space.
     For each cluster, an average confusion, average predicted probability and observed rate of a single class is
     calculated.
     Every sub cluster can be retrieved with the function slice_cluster to perform deeper analysis.
@@ -323,7 +323,7 @@ class InspectorShap(BaseInspector):
 
     def _compute_report(self):
         """
-        Helper function to compute the report of the ispector.
+        Helper function to compute the report of the inspector.
 
         Performs aggregations per cluster id
         """
@@ -353,7 +353,7 @@ class InspectorShap(BaseInspector):
             - average predicted probabilitites
             - average confusion
 
-        If multiple eval_sets were passed in the inspect() functions, the output will contain those aggregations as well
+        If multiple eval_sets were passed in the inspect() functions, the output will contain those aggregations as well.
         The output names will use the sample names provided in the inspect function. Otherwise they will be labelled by
         the suffix sample_{i}, where i is the index of the sample
 
@@ -406,10 +406,10 @@ class InspectorShap(BaseInspector):
                 if not passed the slicing is performed on y passed to inspect
             predicted_proba: Optional parameter - the predicted_proba on which the masking should be performed.
                 if not passed the slicing is performed on predicted_proba generated by inspect method on X and y
-            complementary: flag that returns the cluster_id if set to False, otherwise the complementary dataframe (ie
+            complementary: flag that returns the cluster_id if set to False, otherwise the complementary dataframe (i.e.
                 those with ~mask)
 
-        Returns: tuple: Dataframe of sliced shapley values, series of sliced targets, sliced probabilities
+        Returns: tuple: Dataframe of sliced Shapley values, series of sliced targets, sliced probabilities
         """
         if self.cluster_report is None:
             self.compute()
@@ -484,8 +484,8 @@ class InspectorShap(BaseInspector):
         by concatenating the cluster series, the targets, the probabilities and the measured confusion.
 
         Args:
-            cluster: pd.Series od clusters
-            y: pd.Series od targets
+            cluster: pd.Series of clusters
+            y: pd.Series of targets
             probas: pd.Series of predicted probabilities of the model
             normalize: boolean (if the predicted probabilities should be normalized to the max value
 
