@@ -23,33 +23,49 @@ from probatus.utils import NotFittedError
 
 
 class BaseFitComputeClass(ABC):
+    """
+    Placeholder that must be overwritten by subclass.
+    """
+
     fitted = False
 
     def _check_if_fitted(self):
         """
         Checks if object has been fitted. If not, NotFittedError is raised.
         """
-        if self.fitted is False:
-            raise (
-                NotFittedError(
-                    "The object has not been fitted. Please run fit() method first"
-                )
-            )
+        if not self.fitted:
+            raise (NotFittedError("The object has not been fitted. Please run fit() method first"))
 
     @abstractmethod
     def fit(self, *args, **kwargs):
+        """
+        Placeholder that must be overwritten by subclass.
+        """
         pass
 
     @abstractmethod
     def compute(self, *args, **kwargs):
+        """
+        Placeholder that must be overwritten by subclass.
+        """
         pass
 
     @abstractmethod
     def fit_compute(self, *args, **kwargs):
+        """
+        Placeholder that must be overwritten by subclass.
+        """
         pass
 
 
 class BaseFitComputePlotClass(BaseFitComputeClass):
+    """
+    Base class.
+    """
+
     @abstractmethod
     def plot(self, *args, **kwargs):
+        """
+        Placeholder method for plotting.
+        """
         pass
